Documentation
¶
Index ¶
- func BuildWorkerCoordinatorClientConfig(cfg *config.Config) (*coordinator.Config, error)
- func NewCoordinatorClient(ctx context.Context, cfg *config.Config, registry exec.ServiceRegistry) coordinator.Client
- func NewDAGStore(cfg *config.Config, storeCfg DAGStoreConfig) (exec.DAGStore, error)
- func NewFrontendStoreFactories() frontend.StoreFactories
- func NewScheduler(cfg SchedulerConfig) (*scheduler.Scheduler, error)
- func NewServer(cfg ServerConfig, opts ...frontend.ServerOption) (*frontend.Server, error)
- func NewWorkerCoordinatorClient(ctx context.Context, cfg *config.Config) (coordinator.Client, error)
- type DAGStoreConfig
- type RuntimeStores
- type SchedulerConfig
- type ServerConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildWorkerCoordinatorClientConfig ¶
func BuildWorkerCoordinatorClientConfig(cfg *config.Config) (*coordinator.Config, error)
BuildWorkerCoordinatorClientConfig creates coordinator client config from application config.
func NewCoordinatorClient ¶
func NewCoordinatorClient(ctx context.Context, cfg *config.Config, registry exec.ServiceRegistry) coordinator.Client
NewCoordinatorClient creates a coordinator client for a command process role.
func NewDAGStore ¶
NewDAGStore creates the file-backed DAG store used by command process roles.
func NewFrontendStoreFactories ¶
func NewFrontendStoreFactories() frontend.StoreFactories
NewFrontendStoreFactories returns the file-backed persistence wiring for the frontend server.
func NewScheduler ¶
func NewScheduler(cfg SchedulerConfig) (*scheduler.Scheduler, error)
NewScheduler creates the scheduler and its process-local stores, monitors, and workers.
func NewServer ¶
func NewServer(cfg ServerConfig, opts ...frontend.ServerOption) (*frontend.Server, error)
NewServer creates the frontend server and process-local telemetry wiring.
func NewWorkerCoordinatorClient ¶
func NewWorkerCoordinatorClient( ctx context.Context, cfg *config.Config, ) (coordinator.Client, error)
NewWorkerCoordinatorClient creates the worker coordinator client.
Types ¶
type DAGStoreConfig ¶
type DAGStoreConfig struct {
Cache *fileutil.Cache[*core.DAG]
SearchPaths []string
SkipDirectoryCreation bool
}
DAGStoreConfig contains process wiring options for creating a DAG store.
type RuntimeStores ¶
RuntimeStores contains runtime stores used by DAG execution.
func NewRuntimeStores ¶
func NewRuntimeStores(ctx context.Context, cfg *config.Config) RuntimeStores
NewRuntimeStores creates the runtime store bundle for a command process role.
func NewRuntimeStoresForConfig ¶
func NewRuntimeStoresForConfig(ctx context.Context, cfg *config.Config) RuntimeStores
NewRuntimeStoresForConfig creates the stores used by worker/runtime execution.
type SchedulerConfig ¶
type SchedulerConfig struct {
Context context.Context
Config *config.Config
QueueStore exec.QueueStore
ProcStore exec.ProcStore
ServiceRegistry exec.ServiceRegistry
DispatchTaskStore exec.DispatchTaskStore
DAGRunLeaseStore exec.DAGRunLeaseStore
EventService *eventstore.Service
LicenseManager *license.Manager
}
SchedulerConfig contains the wiring needed to construct the scheduler process role.
type ServerConfig ¶
type ServerConfig struct {
Context context.Context
Config *config.Config
DAGRunStore exec.DAGRunStore
QueueStore exec.QueueStore
ProcStore exec.ProcStore
DAGRunManager runtime.Manager
ServiceRegistry exec.ServiceRegistry
DAGRunLeaseStore exec.DAGRunLeaseStore
WorkerHeartbeatStore exec.WorkerHeartbeatStore
LicenseManager *license.Manager
ResourceService *resource.Service
}
ServerConfig contains the wiring needed to construct the frontend process role.