Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StartContextRunner ¶
func StartContextRunner(t *testing.T, runner ContextRunner) func()
StartContextRunner starts a context-driven runner and returns a shutdown function that cancels the context and waits for the runner to exit.
Types ¶
type ContextRunner ¶
ContextRunner is a minimal interface for background services that are driven by a cancellable context.
Click to show internal directories.
Click to hide internal directories.